# Arora
Arora is a package for working with sleep diagnostic data. The package is currently still in early development.

To install the package run the command: `pip install arora`

It provides essential features for EDF file processing of sleep data such as
- Segmenting measurements
- Analyzing data through plots and graphs
- Processing data with various mathematical functions

The package is a part of a B. Sc. project in Computer Science for Reykjavik University. The project is done in collaboration with Sleep Revolution which is a research project funded by the European Union, focused on researching Obstructive Sleep Apnea, its diagnostics, and its treatment.

For more information about how to use the package check out the offical documentation: https://sleep-revolution-sleepy.readthedocs-hosted.com/en/latest/.
